@@ -2,7 +2,7 @@ package Catalyst::Plugin::Errors;
 
 use Moose;
 use MRO::Compat;
-use Catalyst::Utils::ContentNegotiation;
+use CatalystX::Utils::ContentNegotiation;
 use Catalyst::Utils;
 
 our %DEFAULT_ERROR_VIEWS = (
@@ -68,10 +68,12 @@ sub dispatch_error {
   my ($c, $code, @args) = @_;
 
   my %args = $c->finalize_error_args($code, $c->$normalize_args(@args));
-  my $chosen_media_type = Catalyst::Utils::ContentNegotiation::content_negotiator
+  my $chosen_media_type = CatalystX::Utils::ContentNegotiation::content_negotiator
     ->choose_media_type(\@accepted, $c->request->header('Accept'))
     ||  $default_media_type;
 
+  $c->log->info("Error dispatch to mediatype: $chosen_media_type");
+
   my $chosen_view = $views{$chosen_media_type};
   my $view_obj = $c->view($chosen_view);
 
